@@ -44,8 +44,9 @@ pub use self::{
     unfix,
     HasRecApp,
     Rec,
-    Rec1,
     RecApp,
+    RecX,
+    Release,
     SharedRecApp,
   },
   session::{
