@@ -61,9 +61,7 @@ pub use self::{
   },
   fix::{
     fix_session,
-    succ_session,
     unfix_session,
-    unfix_session_for,
   },
   forward::forward,
   include::{
