@@ -42,12 +42,10 @@ pub use super::{
   session_1,
   session_2,
   step,
-  succ_session,
   terminate,
   terminate_async,
   terminate_nil,
   unfix_session,
-  unfix_session_for,
   unwrap_session,
   wait,
   wait_session,
